@@ -10,7 +10,8 @@ import time
 import board
 import adafruit_ds1307
 
-i2c = board.I2C()
+i2c = board.I2C()  # uses board.SCL and board.SDA
+# i2c = board.STEMMA_I2C()  # For using the built-in STEMMA QT connector on a microcontroller
 rtc = adafruit_ds1307.DS1307(i2c)
 
 # Lookup table for names of days (nicer printing).
